@@ -96,6 +96,13 @@ fun_homology <- function(msec,
                             style = 3)
         pb_t <- ceiling(max_no / 100)
       }
+      tmp_distant = df_distant[1,]
+      tmp_distant$sample_name = ""
+      tmp_distant$Chr = ""
+      tmp_distant$Pos = 0
+      tmp_distant$Ref = ""
+      tmp_distant$Alt = ""
+      k = 0
       if (dim(df_distant[df_distant$number == 1, ])[1] == 1) {
         tmp_distant <- df_distant[df_distant$number == 1, ][1, ]
         if (tmp_distant$distant_homology > 0) {
